@@ -17,7 +17,7 @@ class ClassificationDatasetTestCase(unittest.TestCase):
     def setUpClass(cls):
         if not exists(join(DATA_ROOT, 'CIFAR10')):
             subprocess.call(
-                'python /workspace/coreml/tasks/data/classification/CIFAR10.py',
+                'python /workspace/coreml/coreml/data/process/CIFAR10.py',
                 shell=True)
 
         classes = np.arange(10).tolist()
